@@ -1,10 +1,8 @@
-from abc import ABC
 from typing import Any
 
 import injection
 
 from cq._core.dispatcher.bus import Bus, SimpleBus, TaskBus
-from cq._core.dto import DTO
 from cq._core.handler import (
     HandlerDecorator,
     MultipleHandlerManager,
@@ -13,22 +11,9 @@ from cq._core.handler import (
 from cq._core.scope import CQScope
 from cq.middlewares.scope import InjectionScopeMiddleware
 
-
-class Message(DTO, ABC):
-    __slots__ = ()
-
-
-class Command(Message, ABC):
-    __slots__ = ()
-
-
-class Event(Message, ABC):
-    __slots__ = ()
-
-
-class Query(Message, ABC):
-    __slots__ = ()
-
+Command = object
+Event = object
+Query = object
 
 type CommandBus[T] = Bus[Command, T]
 type EventBus = Bus[Event, None]
@@ -48,31 +33,18 @@ query_handler: HandlerDecorator[Query, Any] = HandlerDecorator(
 )
 
 
-@injection.singleton(
-    on=CommandBus,
-    ignore_type_hint=True,  # type: ignore[call-arg]
-    inject=False,
-    mode="fallback",
-)
-def new_command_bus[T]() -> CommandBus[T]:
+@injection.singleton(inject=False, mode="fallback")
+def new_command_bus() -> CommandBus:  # type: ignore[type-arg]
     bus = SimpleBus(command_handler.manager)
     bus.add_middlewares(InjectionScopeMiddleware(CQScope.ON_COMMAND))
     return bus
 
 
-@injection.singleton(
-    inject=False,
-    mode="fallback",
-)
+@injection.singleton(inject=False, mode="fallback")
 def new_event_bus() -> EventBus:
     return TaskBus(event_handler.manager)
 
 
-@injection.singleton(
-    on=QueryBus,
-    ignore_type_hint=True,  # type: ignore[call-arg]
-    inject=False,
-    mode="fallback",
-)
-def new_query_bus[T]() -> QueryBus[T]:
+@injection.singleton(inject=False, mode="fallback")
+def new_query_bus() -> QueryBus:  # type: ignore[type-arg]
     return SimpleBus(query_handler.manager)
